local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

a.spells["Auto Shot"] = {
	ID = 75--[[Auto Shot]],
	EnemyTargetNeeded = true,
	NotIfActive = true,
	Check = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "Green", "Pink")
		return x.NoCC and not s.Shooting()
	end,
	NoGCD = true,
}

a.spells["Pet Attack"] = {
	EnemyTargetNeeded = true,
	Override = function(z)
		if x.NoCC and x.PetAlive and x.PetActiveEnemy and not s.SameTargetAsPet() then
			s.FlashPet(PET_ACTION_ATTACK)
		end
	end,
	FlashColor = "Pink",
	NoGCD = true,
}

a.spells["Pet Assist"] = {
	Override = function(z)
		if x.ActiveEnemy and x.PetAlive and not x.PetActiveEnemy and s.Shooting() then
			s.FlashPet(PET_MODE_ASSIST)
		end
	end,
	FlashColor = "Pink",
	NoGCD = true,
}

a.spells["Hunter's Mark"] = {
	ID = 1130--[[Hunter's Mark]],
	Debuff = 1130--[[Hunter's Mark]],
	EarlyRefresh = 5,
	Check = function(z)
		return x.ShouldTemporaryBuff and not s.HasGlyph(132106--[[Glyph of Marked for Death]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["Aspect of the Hawk"] = {
	Type = "form",
	ID = 13165--[[Aspect of the Hawk]],
	Buff = {
		13165--[[Aspect of the Hawk]],
		109260--[[Aspect of the Iron Hawk]],
	},
	BuffUnit = "player",
	NotWhileMoving = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and not s.Moving("player")
	end,
	FlashID = {
		13165--[[Aspect of the Hawk]],
		109260--[[Aspect of the Iron Hawk]],
	},
}

a.spells["Aspect of the Fox while moving in combat"] = {
	Type = "form",
	ID = 82661--[[Aspect of the Fox]],
	Buff = 82661--[[Aspect of the Fox]],
	BuffUnit = "player",
	NotWhileMoving = false,
	Check = function(z)
		return x.ShouldPermanentBuff and s.Moving("player") and s.InCombat()
	end,
}

a.spells["Aspect of the Cheetah while moving"] = {
	Type = "form",
	ID = 5118--[[Aspect of the Cheetah]],
	MyBuff = 5118--[[Aspect of the Cheetah]],
	BuffUnit = "player",
	NotWhileMoving = false,
	Check = function(z)
		return x.ShouldPermanentBuff and s.Moving("player") and not s.InCombat()
	end,
}

a.spells["Explosive Trap (AoE)"] = {
	ID = 13813--[[Explosive Trap]],
	Check = function(z)
		return x.ActiveEnemy and a.AoE()
	end,
	FlashID = {
		13813--[[Explosive Trap]],
		82939--[[Explosive Trap]],
	},
	NoRangeCheck = true,
}

a.spells["Focus Fire at 5 stacks"] = {
	ID = 82692--[[Focus Fire]],
	RequireBuff = 19623--[[Frenzy]],
	RequireStack = 5,
	RequireBuffUnit = "pet",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and x.PetAlive 
	end,
	NoGCD = true,
}

a.spells["Serpent Sting if not ticking"] = {
	ID = 1978--[[Serpent Sting]],
	MyDebuff = 1978--[[Serpent Sting]],
	Run = function(z)
		local travelTime = s.LastSpellTravelTime(77767--[[Cobra Shot]]) or 0
		z.EarlyRefresh = s.CastTime(77767--[[Cobra Shot]]) + travelTime
	end,
	Check = function(z)
		return x.NoCC
	end,
	EnemyTargetNeeded = true,
}

a.spells["Serpent Sting if not ticking and target HP <= 90%"] = {
	ID = 1978--[[Serpent Sting]],
	MyDebuff = 1978--[[Serpent Sting]],
	CheckLast = function(z)
		return x.NoCC and (s.HealthPercent("target") <= 90 or s.Dummy("target"))
	end,
	EnemyTargetNeeded = true,
}

a.spells["Serpent Sting if not ticking and TTD  >= 10"] = {
	ID = 1978--[[Serpent Sting]],
	MyDebuff = 1978--[[Serpent Sting]],
	Run = function(z)
		local travelTime = s.LastSpellTravelTime(77767--[[Cobra Shot]]) or 0
		z.EarlyRefresh = s.CastTime(77767--[[Cobra Shot]]) + travelTime
	end,
	Continue = false,
	Check = function(z)
		return x.NoCC and (s.TimeToDie() or 10) >= 10
	end,
	EnemyTargetNeeded = true,
}

a.spells["Chimera Shot if target HP <= 90%"] = {
	ID = 53209--[[Chimera Shot]],
	CheckLast = function(z)
		return x.NoCC and (s.HealthPercent("target") <= 90 or s.Dummy("target"))
	end,
	EnemyTargetNeeded = true,
}

a.spells["Bestial Wrath if focus > 60"] = {
	ID = 19574--[[Bestial Wrath]],
	Check = function(z)
		return x.ShouldTemporaryBuff and s.InCombat() and s.Power("player", SPELL_POWER_FOCUS) > 60 
	end,
}

a.spells["Multi-Shot (AoE)"] = {
	ID = 2643--[[Multi-Shot]],
	Check = function(z)
		return x.NoCC
	end,
	Run = function(z)
		if a.AoE() then
			z.FlashColor = "White"
			z.Continue = false
		else
			z.FlashColor = "Purple"
			z.Continue = true
		end
	end,
	EnemyTargetNeeded = true,
}

a.spells["Steady Shot (AoE)"] = {
	ID = 56641--[[Steady Shot]],
	Check = function(z)
		return x.NoCC and a.AoE()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Cobra Shot (AoE)"] = {
	ID = 77767--[[Cobra Shot]],
	Check = function(z)
		return x.NoCC and a.AoE()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Kill Shot"] = {
	ID = 53351--[[Kill Shot]],
	Check = function(z)
		return x.NoCC and not a.PreSteadyFocus()
	end,
	EnemyTargetNeeded = true,
}

a.spells["A Murder of Crows"] = {
	ID = 131894--[[A Murder of Crows]],
	Check = function(z)
		return x.NoCC and s.HasTalent(131894--[[A Murder of Crows]]) and not a.PreSteadyFocus()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Stampede"] = {
	ID = 121818--[[Stampede]],
	Check = function(z)
		return x.NoCC 
	end,
	EnemyTargetNeeded = true,
	Continue = true,
	FlashColor = "Yellow",
}

a.spells["Glaive Toss"] = {
	ID = 117050--[[Glaive Toss]],
	Check = function(z)
		return x.NoCC and s.HasTalent(117050--[[Glaive Toss]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["Dire Beast"] = {
	ID = 120679--[[Dire Beast]],
	Check = function(z)
		return x.NoCC and s.HasTalent(120679--[[Dire Beast]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["A Murder of Crows with The Beast Within"] = {
	ID = 120657--[[A Murder of Crows]],
	RequireBuff = 34692--[[The Beast Within]],
	RequireBuffUnit = "player",
	Check = function(z)
		return x.NoCC
	end,
	EnemyTargetNeeded = true,
}

a.spells["Kill Command"] = {
	ID = 34026--[[Kill Command]],
	Check = function(z)
		return x.PetNoCC
	end,
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
}

a.spells["Arcane Shot with Thrill of the Hunt"] = {
	ID = 3044--[[Arcane Shot]],
	RequireBuff = 34720--[[Thrill of the Hunt]],
	RequireBuffUnit = "player",
	Check = function(z)
		return x.NoCC and not a.PreSteadyFocus()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Arcane Shot as focus dump when not hasted"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.NoCC
	end,
	CheckLast = function(z)
		return not a.PreSteadyFocus() and (not a.Hasted() or s.Moving("player")) and a.CanStillCast(53209--[[Chimera Shot]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["Arcane Shot if focus >= 69 or The Beast Within up"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.NoCC
	end,
	CheckLast = function(z)
		return a.CanStillCast(34026--[[Kill Command]]) or s.Buff(34692--[[The Beast Within]],"player")
	end,
	EnemyTargetNeeded = true,
}

a.spells["Arcane Shot if focus >= 67"] = {
	ID = 3044--[[Arcane Shot]],
	Check = function(z)
		return x.NoCC
	end,
	CheckLast = function(z)
		return a.CanStillCast({53301--[[Explosive Shot]], 3674--[[Black Arrow]]})
	end,
	EnemyTargetNeeded = true,
}

a.spells["Steady Shot with Steady Focus < 3"] = {
	ID = 56641--[[Steady Shot]],
	Check = function(z)
		return x.NoCC and a.PreSteadyFocus() and s.MyBuffDuration(53224--[[Steady Focus]], "player") < 3
	end,
	EnemyTargetNeeded = true,
}

a.spells["Steady Shot"] = {
	ID = 56641--[[Steady Shot]],
	Check = function(z)
		return x.NoCC
	end,
	EnemyTargetNeeded = true,
}

a.spells["Cobra Shot BM"] = {
	ID = 77767--[[Cobra Shot]],
	Check = function(z)
		return x.NoCC
	end,
	CheckLast = function(z)
		return (s.CastTime(77767--[[Cobra Shot]]) / 2) < s.SpellCooldown(34026--[[Kill Command]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["Cobra Shot SV"] = {
	ID = 77767--[[Cobra Shot]],
	Check = function(z)
		return x.NoCC
	end,
	CheckLast = function(z)
		return (s.CastTime(77767--[[Cobra Shot]]) / 2) < s.SpellCooldown(53301--[[Explosive Shot]])
	end,
	EnemyTargetNeeded = true,
}

a.spells["Rapid Fire without Haste buffs and without The Beast Within"] = {
	ID = 3045--[[Rapid Fire]],
	MyBuff = 3045--[[Rapid Fire]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and not a.Hasted() and not s.Buff(34692--[[The Beast Within]], "player")
	end,
	Continue = true,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Rapid Fire"] = {
	ID = 3045--[[Rapid Fire]],
	MyBuff = 3045--[[Rapid Fire]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff
	end,
	Continue = true,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Rapid Fire without Haste buffs or TTD <= 30"] = {
	ID = 3045--[[Rapid Fire]],
	MyBuff = 3045--[[Rapid Fire]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and (not a.Hasted() or (s.TimeToDie() <= 30))
	end,
	Continue = true,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Readiness after Rapid Fire"] = {
	ID = 23989--[[Readiness]],
	Check = function(z)
		return x.NoCC and s.HasTalent(109215--[[Posthaste]]) and s.SpellCooldown(3045--[[Rapid Fire]]) > s.GlobalCooldown()
	end,
	NoGCD = true,
}

a.spells["Aimed Shot with Master Marksman"] = {
	ID = 19434--[[Aimed Shot]],
	RequireMyBuff = 82926--[[Fire!]],
	RequireBuffUnit = "player",
	NotWhileMoving = false,
	Check = function(z)
		return x.NoCC and not a.PreSteadyFocus()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Aimed Shot over 90% HP"] = {
	ID = 19434--[[Aimed Shot]],
	NotWhileMoving = true,
	Check = function(z)
		return x.NoCC and s.Health("target") > 0 and s.HealthPercent("target") > 90 and not a.PreSteadyFocus() and not s.Dummy("target")
	end,
	EnemyTargetNeeded = true,
}

a.spells["Aimed Shot when hasted"] = {
	ID = 19434--[[Aimed Shot]],
	RequireBuff = a.HasteCDs,
	RequireBuffUnit = "player",
	NotWhileMoving = true,
	Check = function(z)
		return x.NoCC and not a.PreSteadyFocus()
	end,
	EnemyTargetNeeded = true,
}

a.spells["Call Pet"] = {
	ID = 9--[[Call Pet]],
	Override = function(z)
		if not x.PetAlive and x.ShouldPermanentBuff then
			s.Flash({
				9--[[Call Pet]],
				883--[[Call Pet 1]],
				83242--[[Call Pet 2]],
				83243--[[Call Pet 3]],
				83244--[[Call Pet 4]],
				83245--[[Call Pet 5]],
				982--[[Revive Pet]]})
		end
	end,
}

a.spells["Mend Pet"] = {
	ID = 136--[[Mend Pet]],
	Buff = 136--[[Mend Pet]],
	BuffUnit = "pet",
	EarlyRefresh = 1,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.PetAlive and s.HealthPercent("pet") < 80
	end,
}

a.spells["Explosive Shot"] = {
	ID = 53301--[[Explosive Shot]],
	MyDebuffID = 53301--[[Explosive Shot]],
	EarlyRefresh = 1.9,
	Check = function(z)
		return x.NoCC and not s.SpellOrAuraDelay(53301--[[Explosive Shot]], "target", true)
	end,
	EnemyTargetNeeded = true,
}

a.spells["Black Arrow"] = {
	ID = 3674--[[Black Arrow]],
	MyDebuffID = 3674--[[Black Arrow]],
	Check = function(z)
		return x.NoCC and (s.TimeToDie() or 8) >= 8
	end,
	EnemyTargetNeeded = true,
}

a.spells["Disengage when movement impaired"] = {
	ID = 781--[[Disengage]],
	Check = function(z)
		return s.MovementImpaired("player") and s.HasTalent(109215--[[Posthaste]])
	end,
	FlashCOlor = "Yellow",
	NoGCD = true,
}

a.spells["Silencing Shot"] = {
	ID = 34490--[[Silencing Shot]],
	Debuff = 34490--[[Silencing Shot]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Potion with Bloodlust or TTD <= 60"] = {
	Type = "item",
	ID = 76089--[[Virmen's Bite]],
	Buff = {105697--[[Virmen's Bite]], 79633--[[Potion of the Tol'vir]]},
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and s.Boss()
	end,
	CheckLast = function(z)
		return a.Bloodlust() or ((s.TimeToDie() or 61) <= 60)
	end,
	FlashID = {76089--[[Virmen's Bite]], 58145--[[Potion of the Tol'vir]]},
	FlashColor = "Yellow",
	Continue = true,
}